@@ -45,7 +45,7 @@ def run(osfolder=None):
         print("[PYOS-MANAGER] Running OS with PyOS.core.modules.oracle")
         time.sleep(1)
         try:
-            os.system(f'python3 {osfolder}/run.py')
+            os.system(f'python3 {osfolder}/1/.run.py')
         except Exception:
             print("[PYOS-MANAGER] Failed to run the OS with oracle: CODE 400")
     else: print(f"[PYOS-MANAGER] OS folder has not been identified. Identified as: unknown"); i = input('[!] Run folder? '); ivar = i; makes(ivar); 
\ No newline at end of file
